@@ -171,45 +171,42 @@ impl Module {
 }
 
 /// Generate a css module name based on the location from where it was called.
-#[macro_export]
-macro_rules! css_module_name {
-    () => {{
-        use backtrace::{Backtrace, BacktraceFrame, BacktraceSymbol};
-        use lazy_static::lazy_static;
-        use regex::Regex;
+pub fn css_module_name() -> String {
+    use backtrace::{Backtrace, BacktraceFrame, BacktraceSymbol};
+    use lazy_static::lazy_static;
+    use regex::Regex;
 
-        lazy_static! {
-            static ref NAME_FORMATTER: Regex = Regex::new(r"[^\w]+").unwrap();
-        }
+    lazy_static! {
+        static ref NAME_FORMATTER: Regex = Regex::new(r"[^\w]+").unwrap();
+    }
 
-        fn previous_symbol(level: u32) -> Option<BacktraceSymbol> {
-            let (trace, curr_file, curr_line) = (Backtrace::new(), file!(), line!());
-            let frames = trace.frames();
+    fn previous_symbol(level: u32) -> Option<BacktraceSymbol> {
+        let (trace, curr_file, curr_line) = (Backtrace::new(), file!(), line!());
+        let frames = trace.frames();
 
-            frames
-                .iter()
-                .flat_map(BacktraceFrame::symbols)
-                .skip_while(|s| {
-                    s.filename()
-                        .map(|p| !p.ends_with(curr_file))
-                        .unwrap_or(true)
-                        || s.lineno() != Some(curr_line)
-                })
-                .nth(1 + level as usize)
-                .cloned()
-        }
+        frames
+            .iter()
+            .flat_map(BacktraceFrame::symbols)
+            .skip_while(|s| {
+                s.filename()
+                    .map(|p| !p.ends_with(curr_file))
+                    .unwrap_or(true)
+                    || s.lineno() != Some(curr_line)
+            })
+            .nth(1 + level as usize)
+            .cloned()
+    }
 
-        let symbol = previous_symbol(0);
-        let name = symbol.as_ref().and_then(BacktraceSymbol::name);
+    let symbol = previous_symbol(1);
+    let name = symbol.as_ref().and_then(BacktraceSymbol::name);
 
-        if let Some(name) = name {
-            NAME_FORMATTER
-                .replace_all(&format!("{:?}", name), "_")
-                .to_string()
-        } else {
-            "unknown_module".to_string()
-        }
-    }};
+    if let Some(name) = name {
+        NAME_FORMATTER
+            .replace_all(&format!("{:?}", name), "_")
+            .to_string()
+    } else {
+        "unknown_module".to_string()
+    }
 }
 
 /// Make a [`Module`] from a string.
@@ -228,7 +225,7 @@ macro_rules! css_module_name {
 #[macro_export]
 macro_rules! css_module {
     ($stylesheet:expr) => {{
-        Module::new(&css_module_name!(), $stylesheet)
+        Module::new(&css_module_name(), $stylesheet)
     }};
     ($name:expr, $stylesheet:expr) => {{
         Module::new($name, $stylesheet)
