@@ -31,8 +31,10 @@ fn css_module_does_not_contain_class() {
 #[test]
 fn css_module_get_class() {
     let css = include_css_module!("simple.css");
+    let starts_with = ".macros_css_module_get_class_";
 
     assert_ne!("testOne", css.get("testOne"));
+    assert_eq!(css.stylesheet[0..starts_with.len()], starts_with[..]);
 }
 
 #[test]
