@@ -6,11 +6,16 @@ use css_modules::*;
 fn write_module_to_stylesheet() {
     let mut stylesheet = Stylesheet::new();
     let module = css_module!(".test {}");
+    let starts_with = ".stylesheet_write_module_to_stylesheet_";
+    let ends_with = "test_0 {}";
 
     stylesheet.write(&module).unwrap();
 
     let stylesheet = stylesheet.to_string();
 
-    assert!(stylesheet.starts_with(".stylesheet_write_module_to_stylesheet_closure_"));
-    assert!(stylesheet.ends_with("test_0 {}"));
+    assert_eq!(stylesheet[0..starts_with.len()], starts_with[..]);
+    assert_eq!(
+        stylesheet[stylesheet.len() - ends_with.len()..],
+        ends_with[..]
+    );
 }
